Module coroutine

Module coroutine 

Coroutine (thread) objects (P05). A coroutine owns a full execution context — value stack, call frames, open upvalues, to-be-closed slots and stack top — that is swapped into the running Vm while it is active and saved back here while it is suspended.

Structs

Coro
A Lua coroutine (thread) — one independent execution context plus its saved value/frame stacks and resume linkage.

Enums

CoroStatus
Lua coroutine status (PUC coroutine.status).