pub struct LocVar {
pub name: Box<str>,
pub reg: u32,
pub start_pc: u32,
pub end_pc: u32,
}Expand description
Debug record for a local variable: its name and the pc range over which it
occupies register reg. Used to name registers in error messages and
debug.getinfo (PUC LocVar).
Fields
name: Box<str>Local-variable name.
reg: u32Register holding the variable while in scope.
start_pc: u32First pc where the variable is live.
end_pc: u32Pc one past the last where the variable is live.